@@ -2,7 +2,7 @@
 import time
 import json
 import requests
-from requests.exceptions import ConnectionError
+from requests.exceptions import ConnectionError, Timeout
 from functools import wraps
 
 from pagador import settings
@@ -88,7 +88,7 @@ class Conexao(object):
                 return autenticacao
         return requisicao_url
 
-    @retry(ConnectionError, tries=3, delay=2, backoff=2)
+    @retry((ConnectionError, Timeout), tries=3, delay=2, backoff=2)
     def faz_request(self, metodo, url):
         if self.servico.formato_de_envio == FormatoDeEnvio.querystring:
             resposta = getattr(requests, metodo)(url, params=self.dados_envio, headers=self.headers, timeout=settings.REQUEST_BASE_TIMEOUT)
