@@ -29,6 +29,7 @@ class FormaDePagamento(models.FormaPagamento, Plugavel):
                 pgc.pagamento_configuracao_quantidade_parcela_sem_juros,
                 pgc.pagamento_configuracao_juros_valor,
                 pgc.pagamento_configuracao_valor_minimo_parcela,
+                pgc.pagamento_configuracao_aplicacao_id,
                 pgc.conta_id
            FROM configuracao.tb_pagamento as pg
            LEFT OUTER JOIN configuracao.tb_pagamento_configuracao as pgc on (pgc.pagamento_id = pg.pagamento_id AND pgc.conta_id=%s)
@@ -116,6 +117,7 @@ class FormaDePagamento(models.FormaPagamento, Plugavel):
                 forma_pagamento["desconto_tipo"] = self.pagamento_configuracao_desconto_tipo
                 forma_pagamento["desconto_valor"] = '{0:.2f}'.format(self.pagamento_configuracao_desconto_valor)
             forma_pagamento["ativo_para_a_conta"] = self.pagamento_configuracao_ativo
+            forma_pagamento["aplicacao"] = self.pagamento_configuracao_aplicacao_id
             forma_pagamento["configurado"] = self.configurado is not None
             forma_pagamento["maximo_parcelas"] = self.pagamento_configuracao_quantidade_parcela_maxima
             forma_pagamento["parcelas_sem_juros"] = self.pagamento_configuracao_quantidade_parcela_sem_juros
